<?php

/**
 * The file that defines the core plugin class
 *
 * A class definition that includes attributes and functions used across both the
 * public-facing side of the site and the admin area.
 *
 * @link       https://codecanyon.net/user/kamleshyadav
 * @since      1.0.0
 *
 * @package    Wcreferralscheme
 * @subpackage Wcreferralscheme/includes
 */

/**
 * The core plugin class.
 *
 * This is used to define internationalization, admin-specific hooks, and
 * public-facing site hooks.
 *
 * Also maintains the unique identifier of this plugin as well as the current
 * version of the plugin.
 *
 * @since      1.0.0
 * @package    Wcreferralscheme
 * @subpackage Wcreferralscheme/includes
 * @author     Kamleshyadav <ajay.shrivas@himanshusofttech.com>
 */
class Wcreferralscheme {

	/**
	 * The loader that's responsible for maintaining and registering all hooks that power
	 * the plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      Wcreferralscheme_Loader    $loader    Maintains and registers all hooks for the plugin.
	 */
	protected $loader;

	/**
	 * The unique identifier of this plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      string    $plugin_name    The string used to uniquely identify this plugin.
	 */
	protected $plugin_name;

	/**
	 * The current version of the plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      string    $version    The current version of the plugin.
	 */
	protected $version;

	/**
	 * Define the core functionality of the plugin.
	 *
	 * Set the plugin name and the plugin version that can be used throughout the plugin.
	 * Load the dependencies, define the locale, and set the hooks for the admin area and
	 * the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function __construct() {
		if ( defined( 'WCREFERRALSCHEME_VERSION' ) ) {
			$this->version = WCREFERRALSCHEME_VERSION;
		} else {
			$this->version = '1.0.0';
		}
		$this->plugin_name = 'wcreferralscheme';

		$this->load_dependencies();
		$this->set_locale();
		$this->define_admin_hooks();
		$this->define_public_hooks();

	}

	/**
	 * Load the required dependencies for this plugin.
	 *
	 * Include the following files that make up the plugin:
	 *
	 * - Wcreferralscheme_Loader. Orchestrates the hooks of the plugin.
	 * - Wcreferralscheme_i18n. Defines internationalization functionality.
	 * - Wcreferralscheme_Admin. Defines all hooks for the admin area.
	 * - Wcreferralscheme_Public. Defines all hooks for the public side of the site.
	 *
	 * Create an instance of the loader which will be used to register the hooks
	 * with WordPress.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function load_dependencies() {

		/**
		 * The class responsible for orchestrating the actions and filters of the
		 * core plugin.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-wcreferralscheme-loader.php';

		/**
		 * The class responsible for defining internationalization functionality
		 * of the plugin.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-wcreferralscheme-i18n.php';

		/**
		 * The class responsible for defining all actions that occur in the admin area.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'admin/class-wcreferralscheme-admin.php';

		/**
		 * The class responsible for defining all actions that occur in the public-facing
		 * side of the site.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'public/class-wcreferralscheme-public.php';

		$this->loader = new Wcreferralscheme_Loader();

	}

	/**
	 * Define the locale for this plugin for internationalization.
	 *
	 * Uses the Wcreferralscheme_i18n class in order to set the domain and to register the hook
	 * with WordPress.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function set_locale() {

		$plugin_i18n = new Wcreferralscheme_i18n();

		$this->loader->add_action( 'plugins_loaded', $plugin_i18n, 'load_plugin_textdomain' );

	}

	/**
	 * Register all of the hooks related to the admin area functionality
	 * of the plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function define_admin_hooks() {

		$plugin_admin = new Wcreferralscheme_Admin( $this->get_plugin_name(), $this->get_version() );

		$this->loader->add_action( 'admin_enqueue_scripts', $plugin_admin, 'enqueue_styles' );
		$this->loader->add_action( 'admin_enqueue_scripts', $plugin_admin, 'enqueue_scripts' );
		
		$this->loader->add_filter( 'woocommerce_settings_tabs_array', $plugin_admin, 'wcreferralscheme_add_section' ,50);
		
		$this->loader->add_action( 'woocommerce_settings_tabs_referralsetting', $plugin_admin, 'wcreferralscheme_settings_tab' );
		
		$this->loader->add_action( 'woocommerce_update_options_referralsetting', $plugin_admin, 'wcreferralscheme_update_settings' );

	}

	/**
	 * Register all of the hooks related to the public-facing functionality
	 * of the plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function define_public_hooks() {

		$plugin_public = new Wcreferralscheme_Public( $this->get_plugin_name(), $this->get_version() );

		$this->loader->add_action( 'wp_enqueue_scripts', $plugin_public, 'enqueue_styles' );
		$this->loader->add_action( 'wp_enqueue_scripts', $plugin_public, 'enqueue_scripts' );
		
		$this->loader->add_filter('woocommerce_account_menu_items',$plugin_public,'wcreferralscheme_addoption');
		  
		$this->loader->add_action('init',$plugin_public,'wcreferralscheme_addoption_endpoints');
		
        $this->loader->add_action('woocommerce_account_referralcode_endpoint',$plugin_public,'wcreferralscheme_addoption_content');
        
        $this->loader->add_action('woocommerce_register_form',$plugin_public,'wcreferralscheme_add_refarralcodefiled');
        
        $this->loader->add_action('woocommerce_created_customer',$plugin_public,'wcreferralscheme_save_extra_register_fields');
        
        $this->loader->add_action('woocommerce_review_order_before_payment',$plugin_public,'wcreferralscheme_checkout_checkbox_choice');
        
       $this->loader->add_action('woocommerce_cart_calculate_fees',$plugin_public,'wcreferralscheme_checkout_radio_choice_point');
       
       $this->loader->add_action('wp_footer',$plugin_public,'wcreferralscheme_checkout_radio_choice_refresh');
       
       $this->loader->add_action('wp_ajax_woo_get_ajax_data',$plugin_public,'wcreferralscheme_checkout_radio_choice_set_session');
       
       $this->loader->add_action('wp_ajax_nopriv_woo_get_ajax_data',$plugin_public,'wcreferralscheme_checkout_radio_choice_set_session'); 
       
       $this->loader->add_action('woocommerce_thankyou',$plugin_public,'wcreferralscheme_checkout_save_user_meta'); 
	} 

	/**
	 * Run the loader to execute all of the hooks with WordPress.
	 *
	 * @since    1.0.0
	 */
	public function run() {
		$this->loader->run();
	}

	/**
	 * The name of the plugin used to uniquely identify it within the context of
	 * WordPress and to define internationalization functionality.
	 *
	 * @since     1.0.0
	 * @return    string    The name of the plugin.
	 */
	public function get_plugin_name() {
		return $this->plugin_name;
	}

	/**
	 * The reference to the class that orchestrates the hooks with the plugin.
	 *
	 * @since     1.0.0
	 * @return    Wcreferralscheme_Loader    Orchestrates the hooks of the plugin.
	 */
	public function get_loader() {
		return $this->loader;
	}

	/**
	 * Retrieve the version number of the plugin.
	 *
	 * @since     1.0.0
	 * @return    string    The version number of the plugin.
	 */
	public function get_version() {
		return $this->version;
	}

}
